@@ -35,7 +35,7 @@ def main():
         parser.add_argument('-r', metavar='resolution', type=float, default=1.0, help='voxel resolution in the .tif images')
         parser.add_argument('-d', metavar='dFile', type=str, default=None, help='the destination directory where the output should go to')
         parser.add_argument('-p', metavar='pooling', type=str2bool, default=False, help='optionally activate 2D pooling on the input images')
-        parser.add_argument('-k', metavar='poolingKernel', type=str2bool, default=False, help='optionally pass a kernel size for 2D pooling (default = 5)')
+        parser.add_argument('-k', metavar='poolingKernel', type=int, default=False, help='optionally pass a kernel size for 2D pooling (default = 5)')
         
         args = parser.parse_args()
         
